// _________ .__                           ________               __  .__.__
// \_   ___ \|  | _____    ______ ______  /  _____/  ____   _____/  |_|__|  |
// /    \  \/|  | \__  \  /  ___//  ___/ /   \  ____/ __ \ /    \   __|  |  |
// \     \___|  |__/ __ \_\___ \ \___ \  \    \_\  \  ___/|   |  |  | |  |  |__
//  \______  |____(____  /____  /____  >  \______  /\___  |___|  |__| |__|____/
//         \/          \/     \/     \/          \/     \/     \/
package Entity;

import Interfaces.ActionPersonnage;
import Enum.CapaciteSpeciale;


import java.util.logging.Level;
// Création de la classe Gentil qui est enfant de la classe Personnage et qui utilise l'interface ActionPersonnage
public class Gentil extends Personnage implements ActionPersonnage {
    // Définition des différentes caractéristiques d'un gentil
    private CapaciteSpeciale capaciteSpeciale;
    public Gentil(char symbole, int defense, int pa, int pv, String nom, CapaciteSpeciale capaciteSpeciale) {
        super(symbole, defense, pa, pv, nom);
        this.capaciteSpeciale = capaciteSpeciale;
    }
    public CapaciteSpeciale getCapaciteSpeciale() {
        return capaciteSpeciale;
    }
    public void setCapaciteSpeciale(CapaciteSpeciale capaciteSpeciale) {
        this.capaciteSpeciale = capaciteSpeciale;
    }
    // Permet de pouvoir afficher les caractéristiques d'un gentil dans le terminal
    @Override
    public String toString() {
        return "Gentil{" +
                "nom='" + this.getNom() + '\'' +
                ", pv=" + this.getPv() +
                ", pa=" + this.getPa() +
                ", defense=" + this.getDefense() +
                ", symbole=" + this.getSymbole() +
                ", capaciteSpeciale=" + this.capaciteSpeciale.getNom() +
                '}';
    }
    // Fonction qui permet à un personnage (gentil) d'attaquer sa cible (méchant) et de lui infliger des dégats
    @Override
    public void attaquer(Personnage cible) {
        if (cible != null) { // Si la cible est un personnage
            int degats = this.getPa() - cible.getDefense();
            if (degats < 0) {degats = 0;}
            System.out.println(this.getNom() +" a attaqué " + cible.getNom() + " et lui a infligé " + degats + " points de dégats");
            MyLogger.getInstance().log(this.getNom() +" a attaqué " + cible.getNom() + " et lui a infligé " + degats + " points de dégats");
            cible.setPv(cible.getPv() - degats); // On met à jour les points de vie de la cible
        }
    }
    // Fonction qui permet à un gentil d'utiliser sa capacité spéciale sur un méchant
    @Override
    public void utiliserPouvoir(Personnage cible) { // si c'est un soin le personnage récupère des points de vie, sinon il inflige des dégats à la cible
        if (capaciteSpeciale.estSoins()) {
            System.out.println(this.getNom() + " utilise " + this.capaciteSpeciale.getNom() + " et récupère " + capaciteSpeciale.getEffet() + " PV.");
            MyLogger.getInstance().log(this.getNom() + " utilise " + this.capaciteSpeciale.getNom() + " et récupère " + capaciteSpeciale.getEffet() + " PV.");
            this.setPv(Math.min(50, getPv() + capaciteSpeciale.getEffet())); // Limite des PV à 50
        } else if (capaciteSpeciale.getNom() == "Multi shot") {
            System.out.println(this.getNom() + " utilise " + this.capaciteSpeciale.getNom() + " et attaque trois fois");
            MyLogger.getInstance().log(this.getNom() + " utilise " + this.capaciteSpeciale.getNom() + " et attaque trois fois");
            this.attaquer(cible);
            this.attaquer(cible);
            this.attaquer(cible);
        } else if (capaciteSpeciale.getNom() == "Gonflette") {
            System.out.println(this.getNom() + " utilise " + this.capaciteSpeciale.getNom() + " et augmente ses pv de 25");
            MyLogger.getInstance().log(this.getNom() + " utilise " + this.capaciteSpeciale.getNom() + " et augmente ses pv de 25");
            this.setPv(this.getPv() + capaciteSpeciale.getEffet());
        } else {
            int pa = this.getPa();
            this.setPa(pa + this.capaciteSpeciale.getEffet());
            this.attaquer(cible);
            this.setPa(pa);
        }
        this.setCapaciteSpeciale(null);
        MyLogger.getInstance().log(this.getNom() + " n'a plus de capacité spéciale.");

    }
}
